API Reference
=============

.. currentmodule:: blosc2

.. autofunction:: compress

.. autofunction:: decompress

.. autofunction:: pack_array

.. autofunction:: pack

.. autofunction:: unpack_array

.. autofunction:: unpack

.. autofunction:: clib_info

.. autofunction:: compressor_list

.. autofunction:: detect_number_of_cores

.. autofunction:: free_resources

.. autofunction:: get_clib

.. autofunction:: print_versions

.. autofunction:: set_blocksize

.. autofunction:: set_nthreads

.. autofunction:: set_releasegil

.. autofunction:: set_compressor

.. autofunction:: get_compressor

.. autofunction:: get_blocksize
